[livejournal] r18493: LJSV-1243. Allow users to embed media us...
Committer: gprochaev
LJSV-1243. Allow users to embed media using iframesU trunk/cgi-bin/cleanhtml.pl
Modified: trunk/cgi-bin/cleanhtml.pl
===================================================================
--- trunk/cgi-bin/cleanhtml.pl 2011-03-10 04:44:12 UTC (rev 18492)
+++ trunk/cgi-bin/cleanhtml.pl 2011-03-10 06:19:40 UTC (rev 18493)
@@ -497,7 +497,7 @@
## Allow some iframes from trusted sources (if they are not eaten already)
## YouTube (http://apiblog.youtube.com/2010/07/new-way-to-embed-youtube-videos.html),
## Vimeo, VKontakte, Google Calendar, Google Docs
my $src = $attr->{'src'};
if ($src &&
(
@@ -506,6 +506,7 @@
|| $src =~ m!^http://vkontakte\.ru/video_ext\.php\?oid=(?:\d+)&id=(?:\d+)&hash=[a-zA-Z0-9]+$!
|| $src =~ m!^http://www\.google\.com/calendar/embed\?src=!
|| $src =~ m!^https://docs\.google.com/document/pub\?id=!
+ || $src =~ m!^http://vk.com/video_ext\.php\?oid=(?:\d+)&id=(?:\d+)&hash=[a-zA-Z0-9]+$!
)
) {
## allow
@@ -497,7 +497,7 @@
## Allow some iframes from trusted sources (if they are not eaten already)
## YouTube (http://apiblog.youtube.com/2010/07/new-way-to-embed-youtube-videos.html),
- ## Vimeo, VKontakte, Google Calendar, Google Docs
+ ## Vimeo, VKontakte, Google Calendar, Google Docs, VK.com
my $src = $attr->{'src'};
if ($src &&
